@@ -3,7 +3,7 @@ package JSON::Schema::Modern::Vocabulary::OpenAPI;
 # vim: set ts=8 sts=2 sw=2 tw=100 et :
 # ABSTRACT: Implementation of the JSON Schema OpenAPI vocabulary
 
-our $VERSION = '0.074';
+our $VERSION = '0.075';
 
 use 5.020;
 use Moo;
@@ -119,7 +119,7 @@ JSON::Schema::Modern::Vocabulary::OpenAPI - Implementation of the JSON Schema Op
 
 =head1 VERSION
 
-version 0.074
+version 0.075
 
 =head1 DESCRIPTION
 
@@ -129,7 +129,7 @@ version 0.074
 
 Implementation of the JSON Schema "OpenAPI" vocabulary, indicated in metaschemas
 with the URI C<https://spec.openapis.org/oas/3.1/vocab/base> and formally specified in
-L<https://spec.openapis.org/oas/v3.1.0#schema-object>.
+L<https://spec.openapis.org/oas/v3.1#schema-object>.
 
 This vocabulary is normally made available by using the metaschema
 L<https://spec.openapis.org/oas/3.1/dialect/base>.
@@ -168,7 +168,7 @@ L<https://learn.openapis.org/>
 
 =item *
 
-L<https://spec.openapis.org/oas/v3.1.0>
+L<https://spec.openapis.org/oas/v3.1>
 
 =back
 
